The Robomimic proficient human datasets were collected by 1 proficient operator
using the [RoboTurk](https://roboturk.stanford.edu/) platform (with the
exception of Transport, which had 2 proficient operators working together).
Each dataset consists of 200 successful trajectories.

Each task has two versions: one with low dimensional observations (`low_dim`),
and one with images (`image`).

The datasets follow the [RLDS format](https://github.com/google-research/rlds)
to represent steps and episodes.
